@@ -3,7 +3,7 @@ module Serverspec
     class Interface < Base
       def speed
         ret = backend.run_command(commands.get_interface_speed_of(@name))
-        val = ret[:stdout].strip
+        val = ret.stdout.strip
         val = val.to_i if val.match(/^\d+$/)
         val
       end
