@@ -3,7 +3,7 @@ module Serverspec
     class LinuxKernelParameter < Base
       def value
         ret = backend.run_command("/sbin/sysctl -q -n #{@name}")
-        val = ret[:stdout].strip
+        val = ret.stdout.strip
         val = val.to_i if val.match(/^\d+$/)
         val
       end
