@@ -3,7 +3,7 @@ module Serverspec
     class PhpConfig < Base
       def value
         ret = backend.run_command("php -r 'echo get_cfg_var( \"#{@name}\" );'")
-        val = ret[:stdout]
+        val = ret.stdout
         val = val.to_i if val.match(/^\d+$/)
         val
       end
