@@ -2,9 +2,9 @@ module Serverspec
   module Type
     class Port < Base
       def listening?(protocol)
-        if protocol 
+        if protocol
           protocol = protocol.to_s.downcase
-          unless ["udp", "tcp"].include?(protocol)
+          unless ["udp", "tcp", "tcp6", "udp6"].include?(protocol)
             raise ArgumentError.new("`be_listening` matcher doesn't support #{protocol}")
           end
 
