@@ -14,6 +14,18 @@ describe process("memcached") do
   its(:command) { should eq "ps -C memcached -o args= | head -1" }
 end
 
+describe process("memcached") do
+  let(:stdout) { "nobody\n" }
+  its(:user)  { should eq "nobody" }
+  its(:command) { should eq "ps -C memcached -o user= | head -1" }
+end
+
+describe process("memcached") do
+  let(:stdout) { "nobody\n" }
+  its(:group)  { should eq "nobody" }
+  its(:command) { should eq "ps -C memcached -o group= | head -1" }
+end
+
 describe process("memcached") do
   context "when running" do
     let(:stdout) { " 1407\n" }
